pub enum Section {
Standard(StandardSection),
Custom(CustomSection),
}Expand description
A WebAssembly module section.
It is recommended to import the SectionLike trait for additional functions.
Variants
Implementations
Sourceimpl Section
impl Section
Sourcepub fn new(id: SectionId, payload: Vec<u8>) -> Result<Self, WSError>
pub fn new(id: SectionId, payload: Vec<u8>) -> Result<Self, WSError>
Create a new section with the given identifier and payload.
Sourcepub fn deserialize(reader: &mut impl Read) -> Result<Option<Self>, WSError>
pub fn deserialize(reader: &mut impl Read) -> Result<Option<Self>, WSError>
Create a section from its standard serialized representation.
Sourcepub fn is_signature_header(&self) -> bool
pub fn is_signature_header(&self) -> bool
Return true if the section contains the module’s signatures.
Sourcepub fn is_signature_delimiter(&self) -> bool
pub fn is_signature_delimiter(&self) -> bool
Return true if the section is a signature delimiter.